'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var pluginScaffolderBackend = require('@backstage/plugin-scaffolder-backend');
var k8sApply = require('k8s-apply');

const deployKubernetesAction = () => {
  return pluginScaffolderBackend.createTemplateAction({
    id: "deploy:kubernetes",
    schema: {
      input: {
        required: ["manifest", "authToken", "clusterUrl"],
        type: "object",
        properties: {
          manifest: {
            type: "object",
            description: "The Kubernetes manifest object"
          },
          authToken: {
            type: "string",
            description: "Authentication token to access the Kubernetes cluster"
          },
          clusterUrl: {
            type: "string",
            description: "URL of the Kubernetes cluster"
          }
        }
      }
    },
    async handler(ctx) {
      const { manifest, authToken, clusterUrl } = ctx.input;
      try {
        const response = await k8sApply.applyObject(manifest, {
          server: clusterUrl,
          token: authToken
        });
        ctx.logger.info(`Deployment response: ${JSON.stringify(response)}`);
      } catch (error) {
        ctx.logger.error(`Deployment failed: ${error}`);
        throw error;
      }
    }
  });
};

exports.deployKubernetesAction = deployKubernetesAction;
//# sourceMappingURL=index.cjs.js.map
